// $Revision: 1.3 $
/*
    RJKDOC - A system for program documentation
    Copyright (C) 2000  Richard Kettlewell

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "Paragraph.h"

class Document : public SGMLApplication {
public:
private:
    // possible types of chapter
    enum ChapterType {
	chapter,
	appendix
    };
    // internal state
    ChapterType chapterType;		// current chapter type
    int depth;				// depth into section structure
    vector<int> sections;		// section structure

    // set chapter type
    void setChapterType(ChapterType);
    // introduce a new section, and find its section number
    wstring down();
    // end a section
    void up();
protected:
    // parts of the document
    enum Part {
	titlepage,
	contents,
	body,
	index,
	PARTS
    };
    // internal state
    list<wstring> parts[PARTS];		// the parts of the document
    list<wstring> elements;		// current elements
    Paragraph para;			// current text
    wstring sectionNumber;		// current section number
    wstring sectionName;		// current section name

    // support functions
    // find current section depth
    inline int sectionDepth() {
	return depth;
    }
    // add 1 line
    inline void add(const wstring &line, Part part = body) {
	parts[part].push_back(line);
    }
    inline void addf(const wstring &line, Part part = body) {
	add(sconvert(line), part);
    }
    // add a list of lines
    void add(const list<wstring> &l, Part part = body);
    void addf(const list<wstring> &l, Part part = body);
    // return 1 if we are inside a particular element, else 0
    int inside(const wstring &element);
public:

    // methods
    // constructor and destructor
    Document();
    virtual ~Document();

    // implement methods from SGMLApplication
    virtual void data(const DataEvent &event);    
    virtual void sdata(const SdataEvent &event);
    virtual void startElement(const StartElementEvent &event);
    virtual void endElement(const EndElementEvent &event);

    // static methods
    // convert a CharString to a wstring
    static wstring convertString(const CharString &s);
    // find an attribute value, return 1 on success or 0 on failure
    static int findAttributeValue(const StartElementEvent &event,
				  const wstring &attributeName,
				  wstring &attributeValue);
    // construct a map of ID values to section numbers
    static void findStructure(const char *path,
			      map<wstring, wstring> &idMap,
			      map<wstring, wstring> &sectionMap);
    // return 1 if the event name corresponds to a section, 0
    // otherwise
    static int isSectionEvent(const wstring &event);
};

// Local Variables:
// mode:c++
// comment-column:40
// End:
