// $Revision: 1.6 $
/*
    RJKDOC - A system for program documentation
    Copyright (C) 2000  Richard Kettlewell

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "Document.h"

class HTMLDocument : public Document {
private:
    map<wstring, wstring> idMap;	// reference lookup
    int width;				// page width
    int indent;				// current indent
    list<wstring> style;		// style text
    int manpage;			// in a man page?

    // add a rule
    inline void rule(Part part = body) {
	add(L"<HR>", part);
    }
    // add a heading
    void heading(const wstring &s);
    // set the embedded stylesheet
    void setStyle(const list<wstring> &);
public:
    // constructor creates a new document
    HTMLDocument(map<wstring, wstring> idMap);
    ~HTMLDocument();

    // handle events
    virtual void startElement(const StartElementEvent &event);
    virtual void endElement(const EndElementEvent &event);
    virtual void data(const DataEvent &event);    
    virtual void sdata(const SdataEvent &event);

    // convert and output to a file
    static void convert(const char *path,
			const char *output, FILE *fp,
			const char *stylepath);

    wstring openTag(const wchar_t *tag);
};

// Local Variables:
// mode:c++
// c-basic-offset:4
// comment-column:40
// End:
