// $Revision: 1.3 $
/*
    RJKDOC - A system for program documentation
    Copyright (C) 2000  Richard Kettlewell

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "Document.h"
#include "StyleStack.h"

class ManDocument : public Document, public StyleStack {
    map<wstring, wstring> idMap;	// reference lookup
    string dir;				// output directory
    FILE *fp;				// output file
    char *output;			// output filename
    wstring date;			// last update date
    wstring title;			// title
    int wasPara;			// previous was paragraph?

    // convert to troff
    static wstring troffEscape(const wstring &s);
    // convert to a single string argument
    static wstring troffQuote(const wstring &s);
public:
    // methods
    // constructor and destructor
    ManDocument(map<wstring, wstring> idMap,
		const string &dir = ".",
		const wstring &date = L"");
    virtual ~ManDocument();

    // implement methods from SGMLApplication
    virtual void data(const DataEvent &event);    
    virtual void sdata(const SdataEvent &event);
    virtual void startElement(const StartElementEvent &event);
    virtual void endElement(const EndElementEvent &event);

    // implement methods from StyleStack
    wchar_t baseStyle() const;
    void setStyle(wchar_t);
    
    // convert to man pages
    static void convert(const char *path, const char *dir = ".");
};

// Local Variables:
// mode:c++
// comment-column:40
// End:
