// $Revision: 1.5 $
/*
    RJKDOC - A system for program documentation
    Copyright (C) 2000  Richard Kettlewell

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "Document.h"
#include "StyleStack.h"

class TextDocument : public Document, public StyleStack {
private:
    map<wstring, wstring> idMap;	// reference lookup
    int width;				// page width
    int indent;				// current indent
    wchar_t bullet;			// bullet character

    // add a blank line
    inline void blank(Part part = body) {
	add(L"", part);
    }
    // add a rule
    inline void rule(Part part = body) {
	add(wstring(width, L'-'), part);
    }
    // add formatted text
    void format(int needsep = 1,
		Paragraph::Justification j = Paragraph::left,
		Part part = body);
public:
    // constructor creates a new document
    TextDocument(map<wstring, wstring> idMap, int width = 80,
		 int lm = 4, int rm = 4);
    ~TextDocument();

    // handle events
    virtual void startElement(const StartElementEvent &event);
    virtual void endElement(const EndElementEvent &event);
    virtual void data(const DataEvent &event);    
    virtual void sdata(const SdataEvent &event);

    // implement methods from StyleStack
    wchar_t baseStyle() const;
    void setStyle(wchar_t);

    // escape characters to keep strike-text happy
    wstring escapeString(const wstring &s);
	
    // convert and output to a file
    static void convert(const char *path,
			const char *output, FILE *fp);
};

// Local Variables:
// mode:c++
// comment-column:40
// End:
