// $Revision: 1.7 $
/*
    RJKDOC - A system for program documentation
    Copyright (C) 2000  Richard Kettlewell

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "rjkdoc.h"
#include "HTMLDocument.h"
#include <rgetopt.h>

static const char __attribute__((unused)) cvs[] = "$Header: /cvs/rjkdoc/rjkdoc-html.cc,v 1.7 2000/01/21 14:17:21 richard Exp $";

int debug;
const char *style = NULL;

static const struct rgetopt options[] = {
    {"--style", "Set embedded style", 's', RGETOPT_STRING(&style)},
    {"--debug", "Debug mode", 'd', RGETOPT_INT(&debug, 1)},
    {"", NULL, 0, RGETOPT_HELP},
    {"", NULL, 0, RGETOPT_VERSION},
    {RGETOPT_END},
};

int main(int argc, const char *const *argv) {
    map<wstring, wstring> idMap, sectionMap;
    int n;

    switch((n = rgetopt(argc, argv, options))) {
    case rgetopt_ret_error:
        fprintf(stderr, "Syntax error in arguments\n"
                "Try %s --help for more information\n", argv[0]);
        exit(1);
    case rgetopt_ret_version:
        if(printf("rjkdoc-html %s\n", VERSION) < 0
           || fclose(stdout) < 0) {
            perror("-");
            exit(1);
        }
        exit(0);
    case rgetopt_ret_help:
        if(printf("Usage:\n"
                  "  rjkdoc-html [options ...] input\n"
                  "  rjkdoc-html --help\n"
                  "  rjkdoc-html --version\n"
                  "\n") < 0
           || rgetopt_printhelp(stdout, options) < 0
           || fclose(stdout) < 0) {
            perror("-");
            exit(1);
        }
        exit(0);
    }

    if(n + 1 != argc) {
	fprintf(stderr, "Specify exactly one filename\n"
		"Try `%s --help' for more information\n", argv[0]);
	exit(1);
    }
    
    HTMLDocument::convert(argv[n], "stdout", stdout, style);    
    if(fclose(stdout) < 0) {
	perror("writing to stdout");
	exit(1);
    }
    exit(0);
}

// Local Variables:
// mode:c++
// comment-column:40
// End:
