// $Revision: 1.6 $
/*
    RJKDOC - A system for program documentation
    Copyright (C) 2000  Richard Kettlewell

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "rjkdoc.h"
#include "TextDocument.h"
#include <rgetopt.h>

static const char __attribute__((unused)) cvs[] = "$Header: /cvs/rjkdoc/rjkdoc-text.cc,v 1.6 2000/01/21 14:17:21 richard Exp $";

int debug;

static int overstrike = 0;
static int raw = 0;

static const struct rgetopt options[] = {
    {"--raw", "Raw mode", 'r', RGETOPT_INT(&raw, 1)},
    {"--overstrike", "Overstrike mode", 0, RGETOPT_TOGGLE(&overstrike)},
    {"--debug", "Debug mode", 'd', RGETOPT_INT(&debug, 1)},
    {"", NULL, 0, RGETOPT_HELP},
    {"", NULL, 0, RGETOPT_VERSION},
    {RGETOPT_END},
};

int main(int argc, const char *const *argv) {
    map<wstring, wstring> idMap, sectionMap;
    int n;
    FILE *fp;
    const char *name;

    // we want the default assginments
    signal(SIGCHLD, SIG_DFL);
    signal(SIGPIPE, SIG_DFL);
    switch((n = rgetopt(argc, argv, options))) {
    case rgetopt_ret_error:
        fprintf(stderr, "Syntax error in arguments\n"
                "Try %s --help for more information\n", argv[0]);
        exit(1);
    case rgetopt_ret_version:
        if(printf("rjkdoc-text %s\n", VERSION) < 0
           || fclose(stdout) < 0) {
            perror("-");
            exit(1);
        }
        exit(0);
    case rgetopt_ret_help:
        if(printf("Usage:\n"
                  "  rjkdoc-text [options ...] input\n"
                  "  rjkdoc-text --help\n"
                  "  rjkdoc-text --version\n"
                  "\n") < 0
           || rgetopt_printhelp(stdout, options) < 0
           || fclose(stdout) < 0) {
            perror("-");
            exit(1);
        }
        exit(0);
    }

    if(n + 1 != argc) {
	fprintf(stderr, "Specify exactly one filename\n"
		"Try `%s --help' for more information\n", argv[0]);
	exit(1);
    }

    if(raw) {
	fp = stdout;
	name = "stdout";
    } else {
	if(overstrike) fp = popen("strike-text --overstrike", "w");
	else fp = popen("strike-text --no-overstrike", "w");
	
	if(!fp) {
	    perror("cannot invoke strike-text pipeline");
	    exit(1);
	}
	name = "pipe to strike-text";
    }
    
    TextDocument::convert(argv[n], name, fp);    
    if((n = (raw ? fclose : pclose)(fp)) < 0) {
	perror(name);
	exit(1);
    } else if(raw && n) {
	fprintf(stderr, "strike-text exited with status %#x\n", (unsigned)n);
	exit(1);
    }
    exit(0);
}

// Local Variables:
// mode:c++
// comment-column:40
// End:
