/* $Revision: 1.6 $ */
/*
    RJKDOC - A system for program documentation
    Copyright (C) 2000  Richard Kettlewell

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "rjkdoc.h"
#include <rgetopt.h>

static const char __attribute__((unused)) cvs[] = "$Header: /cvs/rjkdoc/strike-text.c,v 1.6 2000/01/27 13:03:20 richard Exp $";

static int overstrike = 1;

int debug;			/* required */

static const struct rgetopt options[] = {
    {"--overstrike", "Overstrike mode", 0, RGETOPT_TOGGLE(&overstrike)},
    {"", NULL, 0, RGETOPT_HELP},
    {"", NULL, 0, RGETOPT_VERSION},
    {RGETOPT_END},
};

int main(int argc, const char *const *argv) {
    int c;
    int mode = 'R';
    int n;

    switch((n = rgetopt(argc, argv, options))) {
    case rgetopt_ret_error:
        fprintf(stderr, "Syntax error in arguments\n"
                "Try %s --help for more information\n", argv[0]);
        exit(1);
    case rgetopt_ret_version:
        if(printf("strike-text %s\n", VERSION) < 0
           || fclose(stdout) < 0) {
            perror("-");
            exit(1);
        }
        exit(0);
    case rgetopt_ret_help:
        if(printf("Usage:\n"
                  "  strike-text [options ...] < input > output\n"
                  "  strike-text --help\n"
                  "  strike-text --version\n"
                  "\n") < 0
           || rgetopt_printhelp(stdout, options) < 0
           || fclose(stdout) < 0) {
            perror("-");
            exit(1);
        }
        exit(0);
    }

    while((c = getchar()) != EOF) {
	switch(c) {
	case '!':
	    c = getchar();
	    switch(c) {
	    case EOF:
		if(ferror(stdin)) goto stdin_error;
		fprintf(stderr, "unexpected EOF\n");
		exit(1);
	    case 'B':
	    case 'U':
	    case 'R':
		mode = c;
		break;
	    default:
		goto ordinary;
	    }
	    break;
	case '\n':
	case '\t':
	    if(putchar(c) < 0) goto stdout_error;
	    break;
	case ' ':
	default:
	ordinary:
	    if(putchar(c) < 0) goto stdout_error;
	    if(overstrike) switch(mode) {
	    case 'B':
		if(putchar('\b') < 0
		   || putchar(c) < 0) goto stdout_error;
		break;
	    case 'U':
		if(fputs("\b_", stdout) < 0) goto stdout_error;
		break;
	    }
	    break;
	}
    }
    if(ferror(stdin)) {
stdin_error:
	perror("stdin");
	exit(1);
    }
    if(fclose(stdout) < 0) {
stdout_error:
	perror("stdout");
	exit(1);
    }
    return 0;
}
